@@ -67,7 +67,7 @@ def sync(
 	client: Client,
 ) -> Optional[Union[Any, ExtendedUser, Error]]:
 	""" Get the user information for the authenticated user.
-Alternatively, you can also use the `/users/me` endpoint. """
+Alternatively, you can also use the `/users-extended/me` endpoint. """
 
 	return sync_detailed(
 		client=client,
@@ -93,7 +93,7 @@ async def asyncio(
 	client: Client,
 ) -> Optional[Union[Any, ExtendedUser, Error]]:
 	""" Get the user information for the authenticated user.
-Alternatively, you can also use the `/users/me` endpoint. """
+Alternatively, you can also use the `/users-extended/me` endpoint. """
 
 	return (
 		await asyncio_detailed(
