@@ -1,7 +1,7 @@
 from enum import Enum
 
 
-class APICallStatus(str, Enum):
+class ApiCallStatus(str, Enum):
     QUEUED = 'Queued'
     UPLOADED = 'Uploaded'
     IN_PROGRESS = 'In Progress'
