@@ -2,8 +2,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 
 import attr
 
-from ..models.address import Address
-from ..models.phone_number import PhoneNumber
+from ..models.new_address import NewAddress
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="BillingInfo")
@@ -12,9 +11,9 @@ T = TypeVar("T", bound="BillingInfo")
 @attr.s(auto_attribs=True)
 class BillingInfo:
     """ """
-    address: Union[Unset, Address] = UNSET
+    address: Union[Unset, NewAddress] = UNSET
     name: Union[Unset, str] = UNSET
-    phone: Union[Unset, PhoneNumber] = UNSET
+    phone: Union[Unset, str] = UNSET
 
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -23,9 +22,7 @@ class BillingInfo:
         if not isinstance(self.address, Unset):
             address = self.address.value
         name = self.name
-        phone: Union[Unset, str] = UNSET
-        if not isinstance(self.phone, Unset):
-            phone = self.phone.value
+        phone = self.phone
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -43,20 +40,15 @@ class BillingInfo:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
         _address = d.pop("address", UNSET)
-        address: Union[Unset, Address]
+        address: Union[Unset, NewAddress]
         if isinstance(_address, Unset):
             address = UNSET
         else:
-            address = Address(_address)
+            address = NewAddress(_address)
 
         name = d.pop("name", UNSET)
 
-        _phone = d.pop("phone", UNSET)
-        phone: Union[Unset, PhoneNumber]
-        if isinstance(_phone, Unset):
-            phone = UNSET
-        else:
-            phone = PhoneNumber(_phone)
+        phone = d.pop("phone", UNSET)
 
         billing_info = cls(
             address=address,
