@@ -5,7 +5,7 @@ import attr
 from dateutil.parser import isoparse
 
 from ..models.uuid import Uuid
-from ..models.file_source_format import FileSourceFormat
+from ..models.file3_d_import_format import File3DImportFormat
 from ..models.api_call_status import ApiCallStatus
 from ..types import UNSET, Unset
 
@@ -21,7 +21,7 @@ class FileMass:
     id: Union[Unset, str] = UNSET
     mass: Union[Unset, float] = UNSET
     material_density: Union[Unset, float] = UNSET
-    src_format: Union[Unset, FileSourceFormat] = UNSET
+    src_format: Union[Unset, File3DImportFormat] = UNSET
     started_at: Union[Unset, datetime.datetime] = UNSET
     status: Union[Unset, ApiCallStatus] = UNSET
     updated_at: Union[Unset, datetime.datetime] = UNSET
@@ -108,11 +108,11 @@ class FileMass:
         material_density = d.pop("material_density", UNSET)
 
         _src_format = d.pop("src_format", UNSET)
-        src_format: Union[Unset, FileSourceFormat]
+        src_format: Union[Unset, File3DImportFormat]
         if isinstance(_src_format, Unset):
             src_format = UNSET
         else:
-            src_format = FileSourceFormat(_src_format)
+            src_format = File3DImportFormat(_src_format)
 
         _started_at = d.pop("started_at", UNSET)
         started_at: Union[Unset, datetime.datetime]
