@@ -4,6 +4,7 @@ from enum import Enum
 class UnitLengthFormat(str, Enum):
     METER = 'meter'
     FOOT = 'foot'
+    MIL = 'mil'
     INCH = 'inch'
     MILE = 'mile'
     NAUTICAL_MILE = 'nautical_mile'
@@ -16,6 +17,9 @@ class UnitLengthFormat(str, Enum):
     LEAGUE = 'league'
     NAUTICAL_LEAGUE = 'nautical_league'
     YARD = 'yard'
+    MILLIMETER = 'millimeter'
+    CENTIMETER = 'centimeter'
+    KILOMETER = 'kilometer'
 
     def __str__(self) -> str:
         return str(self.value)
